@@ -380,21 +380,23 @@ virCapabilitiesHostNUMAAddCell(virCapsHostNUMA *caps,
 
 /**
  * virCapabilitiesAllocMachines:
- * @machines: machine variants for emulator ('pc', or 'isapc', etc)
- * @nmachines: number of machine variants for emulator
+ * @machines: NULL-terminated list of machine variants for emulator ('pc', or 'isapc', etc)
+ * @nmachines: filled with number of machine variants for emulator
  *
  * Allocate a table of virCapsGuestMachine *from the supplied table
  * of machine names.
  */
 virCapsGuestMachine **
-virCapabilitiesAllocMachines(const char *const *names, int nnames)
+virCapabilitiesAllocMachines(const char *const *names,
+                             int *nnames)
 {
     virCapsGuestMachine **machines;
     size_t i;
 
-    machines = g_new0(virCapsGuestMachine *, nnames);
+    *nnames = g_strv_length((gchar **)names);
+    machines = g_new0(virCapsGuestMachine *, *nnames);
 
-    for (i = 0; i < nnames; i++) {
+    for (i = 0; i < *nnames; i++) {
         machines[i] = g_new0(virCapsGuestMachine, 1);
         machines[i]->name = g_strdup(names[i]);
     }
@@ -402,25 +404,6 @@ virCapabilitiesAllocMachines(const char *const *names, int nnames)
     return machines;
 }
 
-/**
- * virCapabilitiesFreeMachines:
- * @machines: table of vircapsGuestMachinePtr
- *
- * Free a table of virCapsGuestMachine *
- */
-void
-virCapabilitiesFreeMachines(virCapsGuestMachine **machines,
-                            int nmachines)
-{
-    size_t i;
-    if (!machines)
-        return;
-    for (i = 0; i < nmachines && machines[i]; i++) {
-        g_clear_pointer(&machines[i], virCapabilitiesFreeGuestMachine);
-    }
-    g_free(machines);
-}
-
 /**
  * virCapabilitiesAddGuest:
  * @caps: capabilities to extend
@@ -525,6 +508,7 @@ static const struct virCapsGuestFeatureInfo virCapsGuestFeatureInfos[VIR_CAPS_GU
     [VIR_CAPS_GUEST_FEATURE_TYPE_DEVICEBOOT] = { "deviceboot", false },
     [VIR_CAPS_GUEST_FEATURE_TYPE_DISKSNAPSHOT] = { "disksnapshot", true },
     [VIR_CAPS_GUEST_FEATURE_TYPE_HAP] = { "hap", true },
+    [VIR_CAPS_GUEST_FEATURE_TYPE_EXTERNAL_SNAPSHOT] = { "externalSnapshot", false },
 };
 
 
@@ -713,7 +697,7 @@ virCapabilitiesDomainDataLookupInternal(virCaps *caps,
             virBufferAsprintf(&buf, "%s", _("any configuration"));
 
         virReportError(VIR_ERR_INVALID_ARG,
-                       _("could not find capabilities for %s"),
+                       _("could not find capabilities for %1$s"),
                        virBufferCurrentContent(&buf));
         return ret;
     }
@@ -1398,8 +1382,7 @@ virCapabilitiesHostNUMAGetCellCpus(virCapsHostNUMA *caps,
     for (cpu = 0; cell && cpu < cell->ncpus; cpu++) {
         if (virBitmapSetBit(cpumask, cell->cpus[cpu].id) < 0) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("Cpu '%u' in node '%zu' is out of range "
-                             "of the provided bitmap"),
+                           _("Cpu '%1$u' in node '%2$zu' is out of range of the provided bitmap"),
                            cell->cpus[cpu].id, node);
             return -1;
         }
@@ -1560,7 +1543,7 @@ virCapabilitiesGetNodeCacheReadFileUint(const char *prefix,
     if (rv < 0) {
         if (rv == -2) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("File '%s' does not exist"),
+                           _("File '%1$s' does not exist"),
                            path);
         }
         return -1;
@@ -1582,7 +1565,7 @@ virCapabilitiesGetNodeCacheReadFileUllong(const char *prefix,
     if (rv < 0) {
         if (rv == -2) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("File '%s' does not exist"),
+                           _("File '%1$s' does not exist"),
                            path);
         }
         return -1;
@@ -1629,7 +1612,7 @@ virCapabilitiesGetNodeCache(int node,
 
         if (virStrToLong_ui(dname, NULL, 10, &cache.level) < 0) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("unable to parse %s"),
+                           _("unable to parse %1$s"),
                            entry->d_name);
             return -1;
         }
@@ -1655,7 +1638,7 @@ virCapabilitiesGetNodeCache(int node,
         case 2: cache.associativity = VIR_NUMA_CACHE_ASSOCIATIVITY_NONE; break;
         default:
                 virReportError(VIR_ERR_INTERNAL_ERROR,
-                               _("unknown indexing value '%u'"),
+                               _("unknown indexing value '%1$u'"),
                                indexing);
                 return -1;
         }
@@ -1671,7 +1654,7 @@ virCapabilitiesGetNodeCache(int node,
         case 2: cache.policy = VIR_NUMA_CACHE_POLICY_NONE; break;
         default:
                 virReportError(VIR_ERR_INTERNAL_ERROR,
-                               _("unknown write_policy value '%u'"),
+                               _("unknown write_policy value '%1$u'"),
                                write_policy);
                 return -1;
         }
@@ -1851,7 +1834,7 @@ virCapabilitiesHostNUMAInitInterconnectsNode(GArray *interconnects,
 
         if (virStrToLong_ui(dname, NULL, 10, &initNode) < 0) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("unable to parse %s"),
+                           _("unable to parse %1$s"),
                            entry->d_name);
             return -1;
         }
@@ -1915,7 +1898,7 @@ virCapabilitiesHostNUMAInitInterconnects(virCapsHostNUMA *caps)
 
         if (virStrToLong_ui(dname, NULL, 10, &node) < 0) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("unable to parse %s"),
+                           _("unable to parse %1$s"),
                            entry->d_name);
             return -1;
         }
@@ -2260,7 +2243,7 @@ virCapabilitiesInitCaches(virCaps *caps)
             kernel_type = virCacheKernelTypeFromString(type);
             if (kernel_type < 0) {
                 virReportError(VIR_ERR_INTERNAL_ERROR,
-                               _("Unknown cache type '%s'"), type);
+                               _("Unknown cache type '%1$s'"), type);
                 return -1;
             }
 
