@@ -30,7 +30,8 @@ testCompareStatusXMLToXMLFiles(const void *opaque)
                                       VIR_DOMAIN_DEF_PARSE_ACTUAL_NET |
                                       VIR_DOMAIN_DEF_PARSE_PCI_ORIG_STATES |
                                       VIR_DOMAIN_DEF_PARSE_SKIP_VALIDATE |
-                                      VIR_DOMAIN_DEF_PARSE_ALLOW_POST_PARSE_FAIL))) {
+                                      VIR_DOMAIN_DEF_PARSE_ALLOW_POST_PARSE_FAIL |
+                                      VIR_DOMAIN_DEF_PARSE_VOLUME_TRANSLATED))) {
         VIR_TEST_DEBUG("\nfailed to parse '%s'", data->infile);
         goto cleanup;
     }
@@ -40,7 +41,8 @@ testCompareStatusXMLToXMLFiles(const void *opaque)
                                       VIR_DOMAIN_DEF_FORMAT_STATUS |
                                       VIR_DOMAIN_DEF_FORMAT_ACTUAL_NET |
                                       VIR_DOMAIN_DEF_FORMAT_PCI_ORIG_STATES |
-                                      VIR_DOMAIN_DEF_FORMAT_CLOCK_ADJUST))) {
+                                      VIR_DOMAIN_DEF_FORMAT_CLOCK_ADJUST |
+                                      VIR_DOMAIN_DEF_FORMAT_VOLUME_TRANSLATED))) {
         VIR_TEST_DEBUG("\nfailed to format back '%s'", data->infile);
         goto cleanup;
     }
